%define openldap2 1
%define pam_ldap_version 145
%define db_version 4.0.14
Summary: NSS library and PAM module for LDAP.
Name: nss_ldap
Version: 189
Release: 1.7
Source0: ftp://ftp.padl.com/pub/nss_ldap-%{version}.tar.gz
Source1: ftp://ftp.padl.com/pub/pam_ldap-%{pam_ldap_version}.tar.gz
Source2: http://www.sleepycat.com/update/%{db_version}/db-%{db_version}.tar.gz
Source3: nss_ldap.versions
Source4: pam_ldap.versions
Patch0: nss_ldap-185-db.patch
Patch1: pam_ldap-144-dnsconfig.patch
URL: http://www.padl.com/
License: LGPL
Group: System Environment/Base
BuildRoot: %{_tmppath}/%{name}-root
BuildPrereq: autoconf, automake
BuildPrereq: gdbm-devel, krb5-devel, libtool, openldap-devel
BuildPrereq: openssl-devel, /usr/include/security/pam_modules.h
%if %{openldap2}
BuildPrereq: cyrus-sasl-devel, openldap-devel >= 2.0.0
%endif
Requires: nscd
Obsoletes: pam_ldap
Prereq: grep, mktemp, sed, textutils, /sbin/ldconfig

%description
This package includes two LDAP access clients: nss_ldap and pam_ldap.
Nss_ldap is a set of C library extensions that allow X.500 and LDAP
directory servers to be used as a primary source of aliases, ethers,
groups, hosts, networks, protocol, users, RPCs, services, and shadow
passwords (instead of or in addition to using flat files or NIS).

Pam_ldap is a module for Linux-PAM that supports password changes, V2
clients, Netscape's SSL, ypldapd, Netscape Directory Server password
policies, access authorization, and crypted hashes.

%prep
%setup -q -c -a 1 -a 2
pushd nss_ldap-%{version}
%patch0 -p1 -b .db
popd

cp nss_ldap-%{version}/resolve.c pam_ldap-%{pam_ldap_version}/
cp nss_ldap-%{version}/resolve.h pam_ldap-%{pam_ldap_version}/
cp nss_ldap-%{version}/snprintf.c pam_ldap-%{pam_ldap_version}/
cp nss_ldap-%{version}/snprintf.h pam_ldap-%{pam_ldap_version}/

pushd pam_ldap-%{pam_ldap_version}
%patch1 -p1 -b .dnsconfig
aclocal
automake -a
autoheader
autoconf
popd

rm -f pam.d/*.pam_console

cp nss_ldap-%{version}/ANNOUNCE             ANNOUNCE.nss_ldap
cp nss_ldap-%{version}/AUTHORS              AUTHORS.nss_ldap
cp nss_ldap-%{version}/ChangeLog            ChangeLog.nss_ldap
cp nss_ldap-%{version}/COPYING              COPYING.nss_ldap
cp nss_ldap-%{version}/NEWS                 NEWS.nss_ldap
cp nss_ldap-%{version}/README               README.nss_ldap
cp nss_ldap-%{version}/nsswitch.ldap        nsswitch.ldap
cp pam_ldap-%{pam_ldap_version}/AUTHORS     AUTHORS.pam_ldap
cp pam_ldap-%{pam_ldap_version}/ChangeLog   ChangeLog.pam_ldap
cp pam_ldap-%{pam_ldap_version}/COPYING     COPYING.pam_ldap
cp pam_ldap-%{pam_ldap_version}/COPYING.LIB COPYING.LIB.pam_ldap
cp pam_ldap-%{pam_ldap_version}/NEWS        NEWS.pam_ldap
cp pam_ldap-%{pam_ldap_version}/README      README.pam_ldap

%build
# We're building modules here, so make sure -fPIC is always used.
CFLAGS="$RPM_OPT_FLAGS -fPIC"; export CFLAGS
topdir=`pwd`/db-instroot
target_platform=%{_target_platform}
%define _target_platform --target=${target_platform}

# Build db4.
pushd db-%{db_version}/dist
./configure --disable-shared --prefix=${topdir} --enable-compat185 --with-uniquename=_nss_ldap
make
make install
popd

# Use the bundled libdb from here on out.
CPPFLAGS=-I${topdir}/include
export CPPFLAGS
CFLAGS="-I${topdir}/include $CFLAGS"
export CFLAGS
LDFLAGS=-L${topdir}/lib
export LDFLAGS

# Build pam_ldap.
pushd pam_ldap-%{pam_ldap_version}
%configure --libdir=/lib
make

# Relink using the version script.
rm pam_ldap.so
make pam_ldap_so_LDFLAGS="-shared -Wl,--version-script=$RPM_SOURCE_DIR/pam_ldap.versions"
popd

# Build nss_ldap, linking statically with libraries which live outside of /lib.
pushd nss_ldap-%{version}
LDAPLIBS="-lldap -llber"
%if %{openldap2}
LDAPLIBS="$LDAPLIBS -lsasl -lkrb5 -lk5crypto -lcom_err -lssl -lcrypto"
%endif
STATICLIBS="$LDAPLIBS -lgdbm -ldb"
SHAREDLIBS=" -ldl -lresolv -lc"

LIBS="-L/usr/kerberos/lib -Wl,-Bstatic $STATICLIBS -Wl,-Bdynamic $SHAREDLIBS"
export LIBS

%configure \
	--with-ldap=openldap \
	--libdir=/lib \
	--enable-schema-mapping \
	--enable-rfc2307bis
make

# Relink using the version script, pulling in the needed libraries statically.
rm nss_ldap.so
make LIBS="$LIBS" nss_ldap_so_LDFLAGS="-shared -Wl,--version-script=$RPM_SOURCE_DIR/nss_ldap.versions -Wl,-soname=libnss_ldap.so.2"
popd

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/{etc,lib/security,usr/lib}

# Let the nss_ldap install target do its thing.
make -C nss_ldap-%{version} \
	install DESTDIR=$RPM_BUILD_ROOT INST_UID=`id -un` INST_GID=`id -gn`

# Install the nsswitch module in a fashion similar to those which are
# part of glibc.
libcver=`basename /lib/libnss_files-*.so .so | cut -f2 -d-`
install -m755 nss_ldap-%{version}/nss_ldap.so \
	$RPM_BUILD_ROOT/lib/libnss_ldap-${libcver}.so

# Create a symlink from libdir to /lib.
install -m755 -d $RPM_BUILD_ROOT/%{_libdir}
touch $RPM_BUILD_ROOT/rootfile
root=..
while [ ! -e $RPM_BUILD_ROOT/%{_libdir}/${root}/rootfile ] ; do
	root=${root}/..
done
pushd $RPM_BUILD_ROOT/%{_libdir}
ln -s ${root}/lib/libnss_ldap-*.so libnss_ldap.so
popd

# Install the module for PAM.
pushd pam_ldap-%{pam_ldap_version}
install -m755 -d $RPM_BUILD_ROOT/lib/security
install -m755 pam_ldap.so $RPM_BUILD_ROOT/lib/security/

# Install the default configuration file, but change the search bases to
# something generic to avoid overloading padl.com servers and to match
# good practice when using DNS domains in example configurations.
sed 's|dc=padl|dc=example|g' ldap.conf > $RPM_BUILD_ROOT/etc/ldap.conf
chmod 644 $RPM_BUILD_ROOT/etc/ldap.conf
popd

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

# Need to run ldconfig, because older versions of this package included
# the symlink ldconfig now manages.
%triggerpostun -p /sbin/ldconfig -- nss_ldap < 184

%post
/sbin/ldconfig
# Fix a logic mismatch between what the version of authconfig in RHL 7.2 would
# generate and this version of pam_ldap.
if grep -q '^account     required      /lib/security/pam_ldap.so$' /etc/pam.d/system-auth ; then
	newfile=`mktemp /etc/pam.d/system-auth-XXXXXX`
	if [ ! -z "$newfile" ] ; then
		cat /etc/pam.d/system-auth > $newfile
		sed 's,account     required      /lib/security/pam_ldap.so,account     [default=bad success=ok user_unknown=ignore service_err=ignore system_err=ignore] /lib/security/pam_ldap.so,g' $newfile > /etc/pam.d/system-auth
		rm -f $newfile
	fi
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%attr(0755,root,root) /lib/libnss_ldap-*.so
%attr(0755,root,root) /lib/security/*.so*
%attr(0755,root,root) /usr/lib/*.so
%attr(0644,root,root) %config(noreplace) /etc/ldap.conf
%doc nsswitch.ldap *.nss_ldap *.pam_ldap pam_ldap-%{pam_ldap_version}/pam.d

%changelog
* Thu May 16 2002 Nalin Dahyabhai <nalin@redhat.com> 189-1.7
- build for RHL 7/7.1

* Thu May 16 2002 Nalin Dahyabhai <nalin@redhat.com> 189-1.6
- fix up logic generated by authconfig from RHL 7.2 in %%post
- build for RHL 6.x

* Wed May 15 2002 Nalin Dahyabhai <nalin@redhat.com>
- the triggerun should be a trigger postun

* Tue May  7 2002 Nalin Dahyabhai <nalin@redhat.com> 189-1
- rebuild for RHL 7.2/7.3

* Tue May  7 2002 Nalin Dahyabhai <nalin@redhat.com> 189-0.7
- rebuild for RHL 7/7.1

* Tue May  7 2002 Nalin Dahyabhai <nalin@redhat.com> 189-0.6
- update to nss_ldap 189, pam_ldap 145

* Tue May  7 2002 Nalin Dahyabhai <nalin@redhat.com> 188-1
- rebuild for RHL 7.2/7.3

* Tue May  7 2002 Nalin Dahyabhai <nalin@redhat.com> 188-0.7
- rebuild for RHL 7/7.1

* Tue May  7 2002 Nalin Dahyabhai <nalin@redhat.com> 188-0.6
- rebuild for RHL 6.2
- change dependency on pam-devel to /usr/include/security/pam_modules.h
- drop build deps on cyrus-sasl-devel and openldap >= 2.x
- modify pam_ldap versions file so that binutils from RHL 6.2 can parse it
- update to nss_ldap 188
- update to pam_ldap 144

* Fri Apr  5 2002 Nalin Dahyabhai <nalin@redhat.com> 185-1
- update to nss_ldap 185
- update to pam_ldap 140

* Thu Feb 28 2002 Nalin Dahyabhai <nalin@redhat.com> 184-1
- update to pam_ldap 138
- enable rfc2307bis schema support
- version the pam_ldap module
- add the proper soname to the nss_ldap module and remove the symlink
- add a trigger to run ldconfig again when an upgrade removes the symlink,
  which used to be in this package (doh!)
- fix the symlink from %%{_libdir} to the module (for linking directly to it)

* Thu Feb 14 2002 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 184, pam_ldap 137

* Wed Jan 23 2002 Nalin Dahyabhai <nalin@redhat.com> 181-1
- update to nss_ldap 181, pam_ldap 136

* Thu Dec 20 2001 Nalin Dahyabhai <nalin@redhat.com> 175-1
- update to nss_ldap 175, pam_ldap 135

* Tue Nov 27 2001 Nalin Dahyabhai <nalin@redhat.com> 174-1
- update to nss_ldap 174

* Fri Nov 16 2001 Nalin Dahyabhai <nalin@redhat.com> 173-3
- update to pam_ldap 134

* Wed Oct 31 2001 Nalin Dahyabhai <nalin@redhat.com> 173-2
- build nss_ldap with --enable-schema-mapping

* Mon Oct 29 2001 Nalin Dahyabhai <nalin@redhat.com> 173-1
- update to nss_ldap 173, which includes doc updates
- update to pam_ldap 133, which simplifies the dnsconfig patch quite a bit

* Thu Sep  6 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 125, making checking of host attributes configurable

* Fri Aug 31 2001 Nalin Dahyabhai <nalin@redhat.com>
- link statically with libldap again, because libldap is linked with other
  shared libraries now (keeping us from having files in /usr open when we
  go to shut the system down)

* Thu Aug 30 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 172, fixing schema mapping code
- update to pam_ldap 124, incorporating TLS default option and doc fixes

* Mon Aug  6 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 167, adding support for rebinds

* Tue Jul 24 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 164, fixing the timeout problem correctly
- update to pam_ldap 122, fixing escaping of user name in filters

* Thu Jul 12 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 163, fixing the timeout problem
- update to pam_ldap 120
- add gdbm-devel as a buildprereq, because we list it in $LIBS (#48999)
- add db3-devel as a buildprereq (#48999)
- add pam-devel as a buildprereq (#48999)

* Tue Jul 10 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 161
- attempt to fix hangs when no timeout is specified, or the timeout is 0

* Mon Jul  9 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 160, pam_ldap 119

* Thu Jun 28 2001 Nalin Dahyabhai <nalin@redhat.com>
- patch cleanups

* Tue Jun 26 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 159, pam_ldap 118

* Tue Jun 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 153, pam_ldap 117

* Tue May 29 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 152, pam_ldap 111

* Mon May 21 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 108

* Wed Apr 25 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 107

* Thu Apr 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 150 (incorporates the fail patch)
- update to pam_ldap 106

* Wed Mar  7 2001 Nalin Dahyabhai <nalin@redhat.com>
- make nss_ldap fail when attempting to startup TLS fails, because that's what
  we do when LDAPS doesn't work (and what pam_ldap does already)
- add DNS autoconfiguration to pam_ldap

* Tue Mar  6 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 149, minor fixes for compile glitches
- update to pam_ldap 105, minor fixes (as above) and handles shadow expiration

* Fri Mar  2 2001 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Wed Feb 28 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 146 to get a faster initgroups() back-end

* Mon Feb 12 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 143 to get the official fix for the heap corruption

* Fri Feb  9 2001 Nalin Dahyabhai <nalin@redhat.com>
- fix heap corruption when falling back to DNS SRV records for configuration

* Mon Feb  5 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 142, fixes a memory leak

* Mon Jan 29 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 140, fixes a configure bug and an alignment problem

* Fri Jan 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 139

* Mon Jan 15 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 138, which folds in our patch for initgroups
- change the default search base in ldap.conf to dc=example,dc=com

* Wed Jan 10 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 137 and pam_ldap 99
- try to not cause a segfault in _nss_ldap_initgroups

* Wed Jan  3 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 124 and pam_ldap 82

* Thu Dec 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- add a requires: for nscd

* Thu Dec 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- version the NSS module so that it works properly with programs which have
  been linked statically to a different version of an LDAP library, like
  Netscape Communicator

* Wed Dec  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- BuildPrereq gdbm-devel
- pass RPM_OPT_FLAGS as CFLAGS to %%configure
- if protocol version is 2, explicitly set protocol version to 3 before trying
  to start TLS
- add STARTTLS support to nss_ldap
- work around a build-time problem on ia64

* Tue Dec  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- BuildPrereq cyrus-sasl-devel instead of cyrus-sasl

* Mon Nov 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 123 and pam_ldap 82

* Fri Oct 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 122
- link statically with libsasl, require the first devel package that supplied it

* Thu Oct 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 120 and pam_ldap 77

* Wed Oct  4 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 116 and pam_ldap 74

* Fri Sep  7 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Thu Jul 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 67 to fix a bug in template user code
- convert symlink in /usr/lib to a relative one (#16132)

* Thu Jul 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 113 and pam_ldap 66

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Tue Jun 27 2000 Matt Wilson <msw@redhat.com>
- changed all the -,- in attr statements to root,root

* Tue Jun 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap to 63

* Wed May 31 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap to 56

* Tue May 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap to 55
- back out no-threads patch for pam_ldap, not needed any more

* Thu May 25 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 110
- revert prototype patch, looks like a problem with the new glibc after all

* Fri May 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- get libpthread out of the NSS module
- fix prototype problems in getpwXXX()

* Mon May 15 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 109

* Sat Apr 29 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap 51

* Tue Apr 25 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 108 and pam_ldap 49

* Thu Apr 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 48

* Thu Mar 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 107
- note: check http://www.advogato.org/person/lukeh/ for Luke's changelog

* Tue Mar 21 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 106

* Wed Feb  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 105

* Mon Feb  7 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 104 and pam_ldap 46
- disable link against libpthread in pam_ldap

* Tue Feb  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- remove migration tools, because this package requires openldap now, which
  also includes them

* Fri Jan 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 103

* Mon Jan 24 2000 Preston Brown <pbrown@redhat.com>
- fix typo in linuxconf-pair pam cfg file (#7800)

* Tue Jan 11 2000 Preston Brown <pbrown@redhat.com>
- v99, made it require pam_ldap
- added perl migration tools
- integrate pam_ldap stuff

* Fri Oct 22 1999 Bill Nottingham <notting@redhat.com>
- statically link ldap libraries (they're in /usr/lib)

* Tue Aug 10 1999 Cristian Gafton <gafton@redhat.com>
- use the ldap.conf file as an external source
- don't forcibly build the support for version 3
- imported the default spec file from the tarball and fixed it up for RH 6.1
